==> paraHaplo1.3.tar.gz: SNP/SNP_LIB/snp_Random.c <==
#include <stdio.h>
#include <stdlib.h>
#include <time.h>

#include "snp_Config.h"
#include "snp_Random.h"

/* ZkcCX^[ */
#include "dSFMT.h"

/* 0ȏ1̒lԂ֐ */
double myRand()
{
    double result = 0;

    /* Cgݍ݂̃_֐ */
    //result = (double)rand() / (RAND_MAX + 1);
    //return (double)(rand()-1) / (RAND_MAX);
    
    /* NumericalRecipes in C ran2 */
    //result = ran2(&idum);
    //return ran2(&idum);
    
    /* ZkcCX^[ */
    //result = dsfmt_gv_genrand_close_open();
    return dsfmt_gv_genrand_close_open();

    /* resultɊi[蒼returnق͂₢H */
    //return result;
}

/* ֐ */
void initMyRand()
{
    /* n̕ύX */
    srand((unsigned) time(NULL));
    /* ran2̈idum̏l_Ɍ*/
    idum = rand();
    /* ZkcCX^[̗seedݒ */
    dsfmt_gv_init_gen_rand(rand());
}


/* ran2p̒`idefine͗OIɔF߂j */
#define IM1 2147483563
#define IM2 2147483399
#define AM (1.0/IM1)
#define IMM1 (IM1-1)
#define IA1 40014
#define IA2 40692
#define IQ1 53668
#define IQ2 52774
#define IR1 12211
#define IR2 3791
#define NTAB 32
#define NDIV (1+IMM1/NTAB)
#define EPS 1.2e-7
#define RNMX (1.0-EPS)

double ran2(long *idum)
{
    int j;
    long k;
    static long idum2 = 123456789;
    static long iy = 0;
    static long iv[NTAB];
    double temp;

    if (*idum <= 0){
        if (-(*idum) < 1){
            *idum = 1;
        }
        else{
            *idum = -(*idum);
        }
        idum2 = (*idum);
        for (j = NTAB+7; j >= 0; j--){
            k = (*idum) / IQ1;
            *idum = IA1 * (*idum - k * IQ1) - k * IR1;
            if (*idum < 0){
                *idum += IM1;
            }
            if (j < NTAB){
                iv[j] = *idum;
            }
        }
        iy = iv[0];
    }
    k = (*idum) / IQ1;
    *idum = IA1 * (*idum - k * IQ1) - k * IR1;
    if (*idum < 0){
        *idum += IM1;
    }
    k = idum2 / IQ2;
    idum2 = IA2 * (idum2 - k * IQ2) - k * IR2;
    if (idum2 < 0){
        idum2 += IM2;
    }
    j = iy / NDIV;
    iy = iv[j] - idum2;
    iv[j] = *idum;
    if (iy < 1){
        iy += IMM1;
    }
    if ((temp = AM * iy) > RNMX){
        return RNMX;
    }
    else{
        return temp;
    }
}

==> paraHaplo2.2.tar.gz: SNP/SNP_LIB/snp_Random.c <==
#include <stdio.h>
#include <stdlib.h>
#include <time.h>

#include "snp_Config.h"
#include "snp_Random.h"

/* 륻̥ĥ */
#include "dSFMT.h"

/* 0ʾ1̤֤ͤȯؿ */
double myRand()
{
    double result = 0;

    /* CȤ߹ߤΥؿ */
    //result = (double)rand() / (RAND_MAX + 1);
    //return (double)(rand()-1) / (RAND_MAX);
    
    /* NumericalRecipes in C ran2 */
    //result = ran2(&idum);
    //return ran2(&idum);
    
    /* 륻̥ĥ */
    //result = dsfmt_gv_genrand_close_open();
    return dsfmt_gv_genrand_close_open();

    /* result˳ǼľreturnۤϤ䤤 */
    //return result;
}

/* ȯؿ */
void initMyRand()
{
    /* ѹ */
    srand((unsigned) time(NULL));
    /* ran2ΰidumνͤ˷*/
    idum = rand();
    /* 륻̥ĥseed */
    dsfmt_gv_init_gen_rand(rand());
}


/* ran2Ѥdefineʸ㳰Ūǧ */
#define IM1 2147483563
#define IM2 2147483399
#define AM (1.0/IM1)
#define IMM1 (IM1-1)
#define IA1 40014
#define IA2 40692
#define IQ1 53668
#define IQ2 52774
#define IR1 12211
#define IR2 3791
#define NTAB 32
#define NDIV (1+IMM1/NTAB)
#define EPS 1.2e-7
#define RNMX (1.0-EPS)

double ran2(long *idum)
{
    int j;
    long k;
    static long idum2 = 123456789;
    static long iy = 0;
    static long iv[NTAB];
    double temp;

    if (*idum <= 0){
        if (-(*idum) < 1){
            *idum = 1;
        }
        else{
            *idum = -(*idum);
        }
        idum2 = (*idum);
        for (j = NTAB+7; j >= 0; j--){
            k = (*idum) / IQ1;
            *idum = IA1 * (*idum - k * IQ1) - k * IR1;
            if (*idum < 0){
                *idum += IM1;
            }
            if (j < NTAB){
                iv[j] = *idum;
            }
        }
        iy = iv[0];
    }
    k = (*idum) / IQ1;
    *idum = IA1 * (*idum - k * IQ1) - k * IR1;
    if (*idum < 0){
        *idum += IM1;
    }
    k = idum2 / IQ2;
    idum2 = IA2 * (idum2 - k * IQ2) - k * IR2;
    if (idum2 < 0){
        idum2 += IM2;
    }
    j = iy / NDIV;
    iy = iv[j] - idum2;
    iv[j] = *idum;
    if (iy < 1){
        iy += IMM1;
    }
    if ((temp = AM * iy) > RNMX){
        return RNMX;
    }
    else{
        return temp;
    }
}
